@@ -3,6 +3,7 @@
 from .connection_tools import ConnectionTools
 from .crud_tools import CrudTools
 from .database_tools import DatabaseTools
+from .json_service_tools import JsonServiceTools
 from .label_tools import LabelTools
 from .metadata_tools import MetadataTools
 from .profile_tools import ProfileTools
@@ -16,4 +17,5 @@ __all__ = [
     "ProfileTools",
     "DatabaseTools",
     "SyncTools",
+    "JsonServiceTools",
 ]
